import requests
import datetime
import logging
from . import lookups

logger = logging.getLogger(__name__)

def get_date_string(date):
    """
    Converts a python DateTime into the date string used by REBNY
    """
    return date.strftime("%m/%d/%Y %H:%M %p")

class RebnyClient(object):

    def __init__(self, endpoint, api_key):
        self.endpoint = endpoint
        self.api_key = api_key

    def _request(self, url):
        resp = requests.get(url, headers={"ApiKey": self.api_key})
        resp.raise_for_status()
        return resp.json()

    def _get(self, url):
        rows = self._request(url)
        return [lookups.expand_row(r) for r in rows]

    def get_all_listings(self):
        url = self.endpoint + '/listings'
        return self._get(url)

    def get_new_listings(self, hours_previous=24):
        start_date = datetime.datetime.utcnow() - datetime.timedelta(hours=hours_previous)
        return self.get_listings_by_date(start_date)

    def get_listing_by_id(self, listing_id):
        url = self.endpoint + '/listings/' + listing_id
        return self._get(url)

    def get_listings_by_date(self, date):
        """
        Return listings modified after date
        """
        date_string = get_date_string(date)
        url = self.endpoint + '/listings/filter?ListingDate=' + date_string
        return self._get(url)



#!/usr/bin/env python

from setuptools import setup

setup(name='rebnypy',
      version='0.0.3',
      description="A Python library for interacting with the REBNY listing service",
      author='Kevin McCarthy',
      author_email='me@kevinmccarthy.org',
      url='https://github.com/RealGeeks/rebnypy',
      packages = [
        'rebnypy',
      ],
      package_dir={
        'rebnypy': 'rebnypy',
      },
      license='MIT',
      install_requires=['requests'],
      tests_require=['pytest','mock'],
      classifiers=[
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Programming Language :: Python',
          'License :: OSI Approved :: MIT License',
      ],
)



LOOKUPS = {
"AirConditioning": {
    "C":"Central",
    "F":"Free Standing",
    "M":"Multi­Zone",
    "N":"None",
    "T":"Through the Wall",
    "U":"Unknown Type",
    "W":"Window Units",
},

"Borough": {
    "BK":"Brooklyn",
    "BX":"Bronx",
    "NY":"Manhattan",
    "QN":"Queens",
    "SI":"Staten Island",
},

"BuildingAccess": {
    "A":"Attended Elevator",
    "E":"Elevator",
    "K":"Keyed Elevator",
    "N":"None",
    "W":"Walk­up",
},

"BuildingAge": {
    "O":"Post­war",
    "R":"Pre­war",
},

"BuildingType": {
    "D":"Development Site",
    "F":"Loft",
    "G":"Garage",
    "H":"High­Rise",
    "L":"Low­Rise",
    "M":"Mid­Rise",
    "O":"Hotel",
    "P":"Parking Lot",
    "S":"House",
    "T":"Townhouse",
    "V":"Vacant Lot",
},

"Heat": {
    "B":"Baseboard",
    "C":"Central",
    "E":"Electric",
    "G":"Gas",
    "M":"Multi­Zone",
    "O":"Oil",
    "R":"Radiator",
    "U":"Unknown Type",
},

"LeaseTerm": {
    "1":"One Year",
    "2":"Two Year",
    "3":"Short­term",
    "4":"Month­to­month",
    "5":"Specific term",
    "6":"One or Two year",
    "7":"Short or Long term",
},

"LeaseType": {
    "B":"Stabilized Lease",
    "C":"Commercial",
    "N":"Non­Stabilized Lease",
    "On­Line":"Residential, Inc | IDX API documentation v1.0 | Published 11/01/2014 | Page 27 of 29",
    "S":"Stabilized Sublease",
    "U":"Non­Stabilized Sublease",
},

"ListingStatus": {
    "A":"Active",
    "B":"Board Approved",
    "C":"Contract Signed",
    "E":"Leases Signed",
    "H":"TOM",
    "I":"POM",
    "J":"Exclusive Expired",
    "L":"Leases Out",
    "O":"Contract Out",
    "P":"Offer Accepted/Application",
    "R":"Rented",
    "S":"Sold",
},

"ListingStatusRental": {
    "A":"Active",
    "E":"Leases Signed",
    "H":"TOM",
    "I":"POM",
    "J":"Exclusive Expired",
    "L":"Leases Out",
    "P":"Application",
    "R":"Rented",
},

"ListingStatusSale": {
    "A":"Active",
    "B":"Board Approved",
    "C":"Contract Signed",
    "H":"TOM",
    "I":"POM",
    "J":"Exclusive Expired",
    "O":"Contract Out",
    "P":"Offer Accepted",
    "S":"Sold",
},

"ListingType": {
    "A":"Ours Alone",
    "B":"Exclusive",
    "C":"COF",
    "L":"Limited",
    "O":"Open",
    "Y":"Courtesy",
    "Z":"Buyer's Broker",
},

"MediaType": {
    "F":"Floor plan",
    "I":"Interior Photo",
    "M":"Video",
    "O":"Other",
    "V":"Virtual Tour",
},

"Ownership": {
    "C":"Commercial",
    "D":"Condop",
    "G":"Garage",
    "I":"Income Property",
    "M":"Multi­Family",
    "N":"Condo",
    "P":"Co­op",
    "R":"Rental Property",
    "S":"Single Family",
    "T":"Institutional",
    "V":"Development Site",
    "X":"Mixed Use",
},

"PayPeriod": {
    "M":"Monthly",
    "Y":"Yearly",
},

"PetPolicy": {
    "A":"Pets Allowed",
    "C":"Case By Case",
    "D":"No Dogs",
    "N":"No Pets",
    "T":"No Cats",
},

"SalesOrRent": {
    "R":"Apartment for Rent",
    "S":"Apartment for Sale",
    "T":"Building for Sale",
},

"ServiceLevel": {
    "A":"Attended Lobby",
    "C":"Concierge",
    "F":"Full Time Doorman",
    "I":"Voice Intercom",
    "N":"None",
    "P":"Part Time Doorman",
    "S":"Full Service",
    "U":"Virtual Doorman",
    "V":"Video Intercom",
}
}

def expand_row(row):
    output = {}
    for k, v in row.items():
        if k in LOOKUPS:
            output[k] = LOOKUPS[k].get(v,'UNKNOWN')
        else:
            output[k] = v
    return output


